==> qtjambi-qt3drender-5.15.13-sources.jar: io/qt/qt3d/render/QComputeCommand.java <==
package io.qt.qt3d.render;


/**
 * <p>QComponent to issue work for the compute shader on GPU</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qt3drender-qcomputecommand.html">Qt3DRender::QComputeCommand</a></p>
 */
public class QComputeCommand extends io.qt.qt3d.core.QComponent
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QComputeCommand.class);
    
    /**
     * <p>Java wrapper for Qt enum Qt3DRender::QComputeCommand::RunType</p>
     */
    public enum RunType implements io.qt.QtEnumerator {
        Continuous(0),
        Manual(1);

        static {
            QtJambi_LibraryUtilities.initialize();
        }

        private RunType(int value) {
            this.value = value;
        }

        /**
         * {@inheritDoc}
         */
        public int value() {
            return value;
        }

        /**
         * Returns the corresponding enum entry for the given value.
         * @param value
         * @return enum entry
         */
        public static RunType resolve(int value) {
            switch (value) {
            case 0: return Continuous;
            case 1: return Manual;
            default: throw new io.qt.QNoSuchEnumValueException(value);
            }
        }


        private final int value;
    }
    

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qcomputecommand.html#runType-prop">Qt3DRender::QComputeCommand::runTypeChanged()</a></p>
     */
    @io.qt.QtPropertyNotify(name="runType")
    public final Signal0 runTypeChanged = new Signal0();

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qcomputecommand.html#workGroupX-prop">Qt3DRender::QComputeCommand::workGroupXChanged()</a></p>
     */
    @io.qt.QtPropertyNotify(name="workGroupX")
    public final Signal0 workGroupXChanged = new Signal0();

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qcomputecommand.html#workGroupY-prop">Qt3DRender::QComputeCommand::workGroupYChanged()</a></p>
     */
    @io.qt.QtPropertyNotify(name="workGroupY")
    public final Signal0 workGroupYChanged = new Signal0();

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qcomputecommand.html#workGroupZ-prop">Qt3DRender::QComputeCommand::workGroupZChanged()</a></p>
     */
    @io.qt.QtPropertyNotify(name="workGroupZ")
    public final Signal0 workGroupZChanged = new Signal0();
    
    /**
     * <p>Overloaded constructor for {@link #QComputeCommand(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QComputeCommand() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qcomputecommand.html#QComputeCommand">Qt3DRender::QComputeCommand::QComputeCommand(Qt3DCore::QNode*)</a></p>
     */
    @SuppressWarnings({"exports"})
    public QComputeCommand(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QComputeCommand instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qcomputecommand.html#runType-prop">Qt3DRender::QComputeCommand::runType()const</a></p>
     */
    @io.qt.QtPropertyReader(name="runType")
    @io.qt.QtUninvokable
    public final io.qt.qt3d.render.QComputeCommand.RunType runType(){
        return io.qt.qt3d.render.QComputeCommand.RunType.resolve(runType_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this)));
    }
    
    @io.qt.QtUninvokable
    private native int runType_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qcomputecommand.html#runType-prop">Qt3DRender::QComputeCommand::setRunType(Qt3DRender::QComputeCommand::RunType)</a></p>
     */
    @io.qt.QtPropertyWriter(name="runType")
    public final void setRunType(io.qt.qt3d.render.QComputeCommand.RunType runType){
        setRunType_native_Qt3DRender_QComputeCommand_RunType(QtJambi_LibraryUtilities.internal.nativeId(this), runType.value());
    }
    
    private native void setRunType_native_Qt3DRender_QComputeCommand_RunType(long __this__nativeId, int runType);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qcomputecommand.html#setWorkGroupX">Qt3DRender::QComputeCommand::setWorkGroupX(int)</a></p>
     */
    @io.qt.QtPropertyWriter(name="workGroupX")
    public final void setWorkGroupX(int workGroupX){
        setWorkGroupX_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), workGroupX);
    }
    
    private native void setWorkGroupX_native_int(long __this__nativeId, int workGroupX);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qcomputecommand.html#setWorkGroupY">Qt3DRender::QComputeCommand::setWorkGroupY(int)</a></p>
     */
    @io.qt.QtPropertyWriter(name="workGroupY")
    public final void setWorkGroupY(int workGroupY){
        setWorkGroupY_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), workGroupY);
    }
    
    private native void setWorkGroupY_native_int(long __this__nativeId, int workGroupY);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qcomputecommand.html#setWorkGroupZ">Qt3DRender::QComputeCommand::setWorkGroupZ(int)</a></p>
     */
    @io.qt.QtPropertyWriter(name="workGroupZ")
    public final void setWorkGroupZ(int workGroupZ){
        setWorkGroupZ_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), workGroupZ);
    }
    
    private native void setWorkGroupZ_native_int(long __this__nativeId, int workGroupZ);
    
    /**
     * <p>Overloaded function for {@link #trigger(int)}
     *  with <code>frameCount = 1</code>.</p>
     */
    public final void trigger() {
        trigger((int)1);
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qcomputecommand.html#trigger">Qt3DRender::QComputeCommand::trigger(int)</a></p>
     */
    public final void trigger(int frameCount){
        trigger_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), frameCount);
    }
    
    private native void trigger_native_int(long __this__nativeId, int frameCount);
    
    /**
     * <p>Overloaded function for {@link #trigger(int, int, int, int)}
     *  with <code>frameCount = 1</code>.</p>
     */
    public final void trigger(int workGroupX, int workGroupY, int workGroupZ) {
        trigger(workGroupX, workGroupY, workGroupZ, (int)1);
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qcomputecommand.html#trigger-1">Qt3DRender::QComputeCommand::trigger(int,int,int,int)</a></p>
     */
    public final void trigger(int workGroupX, int workGroupY, int workGroupZ, int frameCount){
        trigger_native_int_int_int_int(QtJambi_LibraryUtilities.internal.nativeId(this), workGroupX, workGroupY, workGroupZ, frameCount);
    }
    
    private native void trigger_native_int_int_int_int(long __this__nativeId, int workGroupX, int workGroupY, int workGroupZ, int frameCount);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qcomputecommand.html#workGroupX-prop">Qt3DRender::QComputeCommand::workGroupX()const</a></p>
     */
    @io.qt.QtPropertyReader(name="workGroupX")
    @io.qt.QtUninvokable
    public final int workGroupX(){
        return workGroupX_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int workGroupX_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qcomputecommand.html#workGroupY-prop">Qt3DRender::QComputeCommand::workGroupY()const</a></p>
     */
    @io.qt.QtPropertyReader(name="workGroupY")
    @io.qt.QtUninvokable
    public final int workGroupY(){
        return workGroupY_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int workGroupY_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qcomputecommand.html#workGroupZ-prop">Qt3DRender::QComputeCommand::workGroupZ()const</a></p>
     */
    @io.qt.QtPropertyReader(name="workGroupZ")
    @io.qt.QtUninvokable
    public final int workGroupZ(){
        return workGroupZ_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int workGroupZ_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QComputeCommand(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QComputeCommand(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QComputeCommand instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-qt3drender-6.2.8-sources.jar: io/qt/qt3d/render/QComputeCommand.java <==
package io.qt.qt3d.render;


/**
 * <p>QComponent to issue work for the compute shader on GPU</p>
 * <p>Java wrapper for Qt's class <a href="https://doc.qt.io/qt/qt3drender-qcomputecommand.html">Qt3DRender::QComputeCommand</a></p>
 */
public class QComputeCommand extends io.qt.qt3d.core.QComponent
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QComputeCommand.class);
    
    /**
     * <p>Java wrapper for Qt enum Qt3DRender::QComputeCommand::RunType</p>
     */
    public enum RunType implements io.qt.QtEnumerator {
        Continuous(0),
        Manual(1);

        private RunType(int value) {
            this.value = value;
        }

        /**
         * {@inheritDoc}
         */
        public int value() {
            return value;
        }

        /**
         * Returns the corresponding enum entry for the given value.
         * @param value
         * @return enum entry
         */
        public static RunType resolve(int value) {
            switch (value) {
            case 0: return Continuous;
            case 1: return Manual;
            default: throw new io.qt.QNoSuchEnumValueException(value);
            }
        }


        private final int value;
    }
    

    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qcomputecommand.html#runType-prop">Qt3DRender::QComputeCommand::runTypeChanged()</a></p>
     */
    @io.qt.QtPropertyNotify(name="runType")
    public final Signal0 runTypeChanged = new Signal0();

    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qcomputecommand.html#workGroupX-prop">Qt3DRender::QComputeCommand::workGroupXChanged()</a></p>
     */
    @io.qt.QtPropertyNotify(name="workGroupX")
    public final Signal0 workGroupXChanged = new Signal0();

    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qcomputecommand.html#workGroupY-prop">Qt3DRender::QComputeCommand::workGroupYChanged()</a></p>
     */
    @io.qt.QtPropertyNotify(name="workGroupY")
    public final Signal0 workGroupYChanged = new Signal0();

    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qcomputecommand.html#workGroupZ-prop">Qt3DRender::QComputeCommand::workGroupZChanged()</a></p>
     */
    @io.qt.QtPropertyNotify(name="workGroupZ")
    public final Signal0 workGroupZChanged = new Signal0();
    
    /**
     * <p>Overloaded constructor for {@link #QComputeCommand(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QComputeCommand() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qcomputecommand.html#QComputeCommand">Qt3DRender::QComputeCommand::QComputeCommand(Qt3DCore::QNode*)</a></p>
     */
    @SuppressWarnings({"exports"})
    public QComputeCommand(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QComputeCommand instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qcomputecommand.html#runType-prop">Qt3DRender::QComputeCommand::runType()const</a></p>
     */
    @io.qt.QtPropertyReader(name="runType")
    @io.qt.QtUninvokable
    public final io.qt.qt3d.render.QComputeCommand.RunType runType(){
        return io.qt.qt3d.render.QComputeCommand.RunType.resolve(runType_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this)));
    }
    
    @io.qt.QtUninvokable
    private native int runType_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qcomputecommand.html#runType-prop">Qt3DRender::QComputeCommand::setRunType(Qt3DRender::QComputeCommand::RunType)</a></p>
     */
    @io.qt.QtPropertyWriter(name="runType")
    public final void setRunType(io.qt.qt3d.render.QComputeCommand.RunType runType){
        setRunType_native_Qt3DRender_QComputeCommand_RunType(QtJambi_LibraryUtilities.internal.nativeId(this), runType.value());
    }
    
    private native void setRunType_native_Qt3DRender_QComputeCommand_RunType(long __this__nativeId, int runType);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qcomputecommand.html#setWorkGroupX">Qt3DRender::QComputeCommand::setWorkGroupX(int)</a></p>
     */
    @io.qt.QtPropertyWriter(name="workGroupX")
    public final void setWorkGroupX(int workGroupX){
        setWorkGroupX_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), workGroupX);
    }
    
    private native void setWorkGroupX_native_int(long __this__nativeId, int workGroupX);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qcomputecommand.html#setWorkGroupY">Qt3DRender::QComputeCommand::setWorkGroupY(int)</a></p>
     */
    @io.qt.QtPropertyWriter(name="workGroupY")
    public final void setWorkGroupY(int workGroupY){
        setWorkGroupY_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), workGroupY);
    }
    
    private native void setWorkGroupY_native_int(long __this__nativeId, int workGroupY);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qcomputecommand.html#setWorkGroupZ">Qt3DRender::QComputeCommand::setWorkGroupZ(int)</a></p>
     */
    @io.qt.QtPropertyWriter(name="workGroupZ")
    public final void setWorkGroupZ(int workGroupZ){
        setWorkGroupZ_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), workGroupZ);
    }
    
    private native void setWorkGroupZ_native_int(long __this__nativeId, int workGroupZ);
    
    /**
     * <p>Overloaded function for {@link #trigger(int)}
     *  with <code>frameCount = 1</code>.</p>
     */
    public final void trigger() {
        trigger((int)1);
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qcomputecommand.html#trigger">Qt3DRender::QComputeCommand::trigger(int)</a></p>
     */
    public final void trigger(int frameCount){
        trigger_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), frameCount);
    }
    
    private native void trigger_native_int(long __this__nativeId, int frameCount);
    
    /**
     * <p>Overloaded function for {@link #trigger(int, int, int, int)}
     *  with <code>frameCount = 1</code>.</p>
     */
    public final void trigger(int workGroupX, int workGroupY, int workGroupZ) {
        trigger(workGroupX, workGroupY, workGroupZ, (int)1);
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qcomputecommand.html#trigger-1">Qt3DRender::QComputeCommand::trigger(int,int,int,int)</a></p>
     */
    public final void trigger(int workGroupX, int workGroupY, int workGroupZ, int frameCount){
        trigger_native_int_int_int_int(QtJambi_LibraryUtilities.internal.nativeId(this), workGroupX, workGroupY, workGroupZ, frameCount);
    }
    
    private native void trigger_native_int_int_int_int(long __this__nativeId, int workGroupX, int workGroupY, int workGroupZ, int frameCount);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qcomputecommand.html#workGroupX-prop">Qt3DRender::QComputeCommand::workGroupX()const</a></p>
     */
    @io.qt.QtPropertyReader(name="workGroupX")
    @io.qt.QtUninvokable
    public final int workGroupX(){
        return workGroupX_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int workGroupX_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qcomputecommand.html#workGroupY-prop">Qt3DRender::QComputeCommand::workGroupY()const</a></p>
     */
    @io.qt.QtPropertyReader(name="workGroupY")
    @io.qt.QtUninvokable
    public final int workGroupY(){
        return workGroupY_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int workGroupY_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qcomputecommand.html#workGroupZ-prop">Qt3DRender::QComputeCommand::workGroupZ()const</a></p>
     */
    @io.qt.QtPropertyReader(name="workGroupZ")
    @io.qt.QtUninvokable
    public final int workGroupZ(){
        return workGroupZ_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int workGroupZ_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QComputeCommand(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QComputeCommand(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QComputeCommand instance, QDeclarativeConstructor constructor);
    
}
